Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon CodeGuru Profiler.

Actions, resources, and condition keys for Amazon CodeGuru Profiler - Service Authorization Reference

# Actions, resources, and condition keys for Amazon CodeGuru Profiler

Amazon CodeGuru Profiler (service prefix: `codeguru-profiler` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon CodeGuru Profiler
- Resource types defined by Amazon CodeGuru Profiler
- Condition keys for Amazon CodeGuru Profiler

## Actions defined by Amazon CodeGuru Profiler

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddNotificationChannels | Grants permission to add up to 2 topic ARNs of existing AWS SNS topics to publish notifications | Write | ProfilingGroup* |  |
BatchGetFrameMetricData | Grants permission to get the frame metric data for a Profiling Group | List | ProfilingGroup* |  |
ConfigureAgent [permission only] | Grants permission for an agent to register with the orchestration service and retrieve profiling configuration information | Write | ProfilingGroup* |  |
CreateProfilingGroup | Grants permission to create a profiling group | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
DeleteProfilingGroup | Grants permission to delete a profiling group | Write | ProfilingGroup* |  |
DescribeProfilingGroup | Grants permission to describe a profiling group | Read | ProfilingGroup* |  |
GetFindingsReportAccountSummary | Grants permission to get a summary of recent recommendations for each profiling group in the account | Read |  |  |
GetNotificationConfiguration | Grants permission to get the notification configuration | Read | ProfilingGroup* |  |
GetPolicy | Grants permission to get the resource policy associated with the specified Profiling Group. | Read | ProfilingGroup* |  |
GetProfile | Grants permission to get aggregated profiles for a specific profiling group | Read | ProfilingGroup* |  |
GetRecommendations | Grants permission to get recommendations | Read | ProfilingGroup* |  |
ListFindingsReports | Grants permission to list the available recommendations reports for a specific profiling group | List | ProfilingGroup* |  |
ListProfileTimes | Grants permission to list the start times of the available aggregated profiles for a specific profiling group | List | ProfilingGroup* |  |
ListProfilingGroups | Grants permission to list profiling groups in the account | List |  |  |
ListTagsForResource | Grants permission to list tags for a Profiling Group | List | ProfilingGroup* |  |
PostAgentProfile [permission only] | Grants permission to submit a profile collected by an agent belonging to a specific profiling group for aggregation | Write | ProfilingGroup* |  |
PutPermission | Grants permission to update the list of principals allowed for an action group in the resource policy associated with the specified Profiling Group. | Permissions management | ProfilingGroup* |  |
RemoveNotificationChannel | Grants permission to delete an already configured SNStopic arn from the notification configuration | Write | ProfilingGroup* |  |
RemovePermission | Grants permission to remove the permission of specified Action Group from the resource policy associated with the specified Profiling Group. | Permissions management | ProfilingGroup* |  |
SubmitFeedback | Grants permission to submit user feedback for useful or non useful anomaly | Write | ProfilingGroup* |  |
TagResource | Grants permission to add or overwrite tags to a Profiling Group | Tagging | ProfilingGroup* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to remove tags from a Profiling Group | Tagging | ProfilingGroup* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UpdateProfilingGroup | Grants permission to update a specific profiling group | Write | ProfilingGroup* |  |

## Resource types defined by Amazon CodeGuru Profiler

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
ProfilingGroup | `arn:$ { Partition}:codeguru-profiler:$ { Region}:$ { Account}:profilingGroup/$ { profilingGroupName}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon CodeGuru Profiler

Amazon CodeGuru Profiler defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.